ledger.Journal (Journal) — amici1

# `ledger.Journal` (Journal)

Journal(id, ref, seqno, name, build_method, template, trade_type, voucher_type, journal_group, auto_check_clearings, auto_fill_suggestions, force_sequence, preliminary, account, partner, printed_name, dc, yearly_numbering, must_declare, uploads_volume, printed_name_de, printed_name_fr, name_de, name_fr)

Master tables : ledger.Journals (Journals), ledger.JournalsOverview (Journals)

Slave tables : ledger.MatchRulesByJournal (Match rules)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Reference (ref) : The reference. This must be either empty or unique.

- No. (seqno) : The sequence number of this item with its parent.

- Designation (name) : See `<lino.utils.mldbc.fields.BabelCharField: name>`.

- Print method (build_method) : A pointer to an item of lino.modlib.printing.choicelists.BuildMethods.

- Template (template) : See PrintableType.template.

- Trade type (trade_type) : Pointer to TradeTypes.

- Voucher type (voucher_type) : Pointer to an item of VoucherTypes.

- Journal group (journal_group) : Pointer to an item of JournalGroups.

- Check clearing (auto_check_clearings) : Whether to automatically check and update the ‘cleared’ status of involved transactions when (de)registering a voucher of this journal.

- Fill suggestions (auto_fill_suggestions) : Whether to automatically fill voucher item from due payments of the partner when entering a financial voucher.

- Force chronological sequence (force_sequence) : See `<django.db.models.fields.BooleanField: force_sequence>`.

- Preliminary (preliminary) : Whether transactions in this journal are considered preliminary.

- Account (account) : The account to use for the counter-movements generated by vouchers in this journal.

- Organization (partner) : The partner to use as default partner for all vouchers in this journal.

- Printed document designation (printed_name) : See `<lino.utils.mldbc.fields.BabelCharField: printed_name>`.

- Primary booking direction (dc) : The primary booking direction. Voucher items in this direction increase the total amount of the voucher.

- Yearly numbering (yearly_numbering) : Whether the number of vouchers should restart at 1 every year.

- must declare (must_declare) : See `<django.db.models.fields.BooleanField: must_declare>`.

- Library volume (uploads_volume) : See `<django.db.models.fields.related.ForeignKey: uploads_volume>`.

- Printed document designation (de) (printed_name_de) : See `<django.db.models.fields.CharField: printed_name_de>`.

- Printed document designation (fr) (printed_name_fr) : See `<django.db.models.fields.CharField: printed_name_fr>`.

- Designation (de) (name_de) : See `<django.db.models.fields.CharField: name_de>`.

- Designation (fr) (name_fr) : See `<django.db.models.fields.CharField: name_fr>`.

- Bank account (sepa_account) : Your bank account to specify in payment order.

- Name (name_column) : See `lino_xl.lib.ledger.models.Journal.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.ledger.models.Journal.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.ledger.models.Journal.overview`.

- Move (move_buttons) : Displays buttons for certain actions on this row:

Referenced from ledger.MatchRule.journal, ledger.PaymentMethod.journal, ledger.Voucher.journal

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
id | ID |
ref | Reference | The reference. This must be either empty or unique.
seqno | No. | The sequence number of this item with its parent.
name | Designation |
build_method | Print method | A pointer to an item of lino.modlib.printing.choicelists.BuildMethods.
template | Template | See PrintableType.template.
trade_type | Trade type | Pointer to TradeTypes.
voucher_type | Voucher type | Pointer to an item of VoucherTypes.
journal_group | Journal group | Pointer to an item of JournalGroups.
auto_check_clearings | Check clearing | Whether to automatically check and update the ‘cleared’ status of involved transactions when (de)registering a voucher of this journal.
auto_fill_suggestions | Fill suggestions | Whether to automatically fill voucher item from due payments of the partner when entering a financial voucher.
force_sequence | Force chronological sequence |
preliminary | Preliminary | Whether transactions in this journal are considered preliminary.
account | Account | The account to use for the counter-movements generated by vouchers in this journal.
partner | Organization | The partner to use as default partner for all vouchers in this journal.
printed_name | Printed document designation |
dc | Primary booking direction | The primary booking direction. Voucher items in this direction increase the total amount of the voucher.
yearly_numbering | Yearly numbering | Whether the number of vouchers should restart at 1 every year.
must_declare | must declare |
uploads_volume | Library volume |
printed_name_de | Printed document designation (de) |
printed_name_fr | Printed document designation (fr) |
name_de | Designation (de) |
name_fr | Designation (fr) |
sepa_account | Bank account | Your bank account to specify in payment order.
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |
move_buttons | Move | Displays buttons for certain actions on this row: